r19924 - gnucash/trunk/src - Remove variable names that conflict with Python keywords. Relevent when using SWIG autodoc feature for python bindings.

Mike Evans mikee at code.gnucash.org
Fri Dec 10 08:09:50 EST 2010


Author: mikee
Date: 2010-12-10 08:09:50 -0500 (Fri, 10 Dec 2010)
New Revision: 19924
Trac: http://svn.gnucash.org/trac/changeset/19924

Modified:
   gnucash/trunk/src/engine/Account.h
   gnucash/trunk/src/engine/gnc-commodity.h
   gnucash/trunk/src/libqof/qof/gnc-numeric.h
Log:
Remove variable names that conflict with Python keywords.  Relevent when using SWIG autodoc feature for python bindings.

Modified: gnucash/trunk/src/engine/Account.h
===================================================================
--- gnucash/trunk/src/engine/Account.h	2010-12-10 13:09:46 UTC (rev 19923)
+++ gnucash/trunk/src/engine/Account.h	2010-12-10 13:09:50 UTC (rev 19924)
@@ -179,7 +179,7 @@
  *    The guid pointers are stored under the under the kvp
  *    path "gemini".
  */
-Account * xaccCloneAccount (const Account *from, QofBook *book);
+Account * xaccCloneAccount (const Account *source, QofBook *book);
 
 /** The xaccCloneAccountSimple() routine makes a simple copy of the
  *  indicated account, placing it in the indicated book.  It copies
@@ -191,7 +191,7 @@
  *  Note that this routines does *NOT* use the 'gemini' kvp value
  *  to indicate where it was copied from.
  */
-Account * xaccCloneAccountSimple (const Account *from, QofBook *book);
+Account * xaccCloneAccountSimple (const Account *source, QofBook *book);
 
 /** The xaccAccountBeginEdit() subroutine is the first phase of
  *    a two-phase-commit wrapper for account updates. */

Modified: gnucash/trunk/src/engine/gnc-commodity.h
===================================================================
--- gnucash/trunk/src/libqof/qof/gnc-numeric.h	2010-12-10 13:09:46 UTC (rev 19923)
+++ gnucash/trunk/src/libqof/qof/gnc-numeric.h	2010-12-10 13:09:50 UTC (rev 19924)
@@ -263,7 +263,7 @@
  *  but GNC_DENOM_AUTO is not recognized; a denominator
  *  must be specified either explicitctly or through sigfigs.
  */
-gnc_numeric double_to_gnc_numeric(double in, gint64 denom,
+gnc_numeric double_to_gnc_numeric(double n, gint64 denom,
                                   gint how);
 
 /** Read a gnc_numeric from str, skipping any leading whitespace.
@@ -294,7 +294,7 @@
 }
 
 /** Convert numeric to floating-point value. */
-gdouble      gnc_numeric_to_double(gnc_numeric in);
+gdouble      gnc_numeric_to_double(gnc_numeric n);
 
 /** Convert to string. The returned buffer is to be g_free'd by the
  *  caller (it was allocated through g_strdup) */
@@ -447,7 +447,7 @@
  *  specified denominator under standard arguments
  *  'denom' and 'how'.
  */
-gnc_numeric gnc_numeric_convert(gnc_numeric in, gint64 denom,
+gnc_numeric gnc_numeric_convert(gnc_numeric n, gint64 denom,
                                 gint how);
 
 #if 0
@@ -455,14 +455,14 @@
 /* Same as gnc_numeric_convert, but return a remainder
  *  value for accumulating conversion error.
 */
-gnc_numeric gnc_numeric_convert_with_error(gnc_numeric in, gint64 denom,
+gnc_numeric gnc_numeric_convert_with_error(gnc_numeric n, gint64 denom,
         gint how,
         gnc_numeric * error);
 #endif
 
 /** Return input after reducing it by Greated Common Factor (GCF)
  *  elimination */
-gnc_numeric gnc_numeric_reduce(gnc_numeric in);
+gnc_numeric gnc_numeric_reduce(gnc_numeric n);
 
 /** Attempt to convert the denominator to an exact power of ten without
  *  rounding.



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/engine/gnc-commodity.h	2010-12-10 13:09:46 UTC (rev 19923)
+++ gnucash/trunk/src/engine/gnc-commodity.h	2010-12-10 13:09:50 UTC (rev 19924)
@@ -941,12 +941,12 @@
 gnc_commodity_table * gnc_commodity_table_new(void);
 void          gnc_commodity_table_destroy(gnc_commodity_table * table);
 
 /** Given the commodity 'from', this routine will find and return the
  *   equivalent commodity (commodity with the same 'unique name') in
  *   the indicated book.  This routine is primarily useful for setting
  *   up clones of things across multiple books.
  */
-gnc_commodity * gnc_commodity_obtain_twin (const gnc_commodity *from, QofBook *book);
+gnc_commodity * gnc_commodity_obtain_twin (const gnc_commodity *findlike, QofBook *book);
 
 /** You should probably not be using gnc_commodity_table_register()
  * It is an internal routine for registering the gncObject for the
@@ -941,12 +941,12 @@
 void          gnc_commodity_table_destroy(gnc_commodity_table * table);
 
-/** Given the commodity 'from', this routine will find and return the
+/** Given the commodity 'findlike', this routine will find and return the
  *   equivalent commodity (commodity with the same 'unique name') in
  *   the indicated book.  This routine is primarily useful for setting

Modified: gnucash/trunk/src/libqof/qof/gnc-numeric.h
===================================================================